<?php
require_once 'lib/abstract_preloaded_regular_screen.php';

/*
 * Root screen wich should show 3 groups: videos, audio, photos
 */
class AudioArtistListScreen extends AbstractPreloadedRegularScreen
{
    private $l;
    const ID = 'audio_artist_list';

    public static function get_media_url_str()
    {
        return MediaURL::encode(array('screen_id' => self::ID));
    }

    

    public function __construct(MobileMediaLocalization $l)
    {
        $this->l = $l;
        parent::__construct(
            self::ID, $this->get_folder_views());
    }

    

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        return array(
            GUI_EVENT_KEY_ENTER => ActionFactory::open_folder(),
        );
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        try
        {
            $url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_music_artists';
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on server side: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        if (is_null($doc))
            throw new Exception('Can not fetch movie info');

        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        
        //hd_print("retrieved:\n".print_r($xml, true));
        $ui_items = array();
        
        foreach ($xml->items->item as $item)
        {
            hd_print("id:\n".print_r($item->id[0], true));
            $ui_items[] = array
            (
                PluginRegularFolderItem::media_url => AudioTrackListScreen::get_media_url_str(strval($item->id[0])),
                PluginRegularFolderItem::caption => strval($item->author),
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'plugin_file://icons/artists.png',
                    ViewItemParams::item_detailed_icon_path => 'plugin_file://icons/artists.png'
                )
            );
        }
        
        return $ui_items;
    }

    
    /*
    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        try
        {
            $url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_music_list';
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on server side: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        
        
        if (is_null($doc))
            throw new Exception('Can not fetch movie info');

        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        
        //hd_print("retrieved:\n".print_r($xml, true));
        
        $ui_items = array();
        
        foreach ($xml->items->item as $item)
        {
            $seconds = intval($item->length);
            $mins = floor( $seconds / 60 );
            $secs = floor( $seconds - ($mins*60) );
            $length = sprintf('%1$02d', $mins) 
                . ':' . sprintf('%1$02d', $secs);
            $caption = $item->author . ' - ' . $item->title . ' - ' . $length;
            
            //hd_print("operating item:\n".print_r($item, true));
            $ui_items[] = array
            (
                PluginRegularFolderItem::media_url => 
                    MediaURL::encode(array(
                        'audio_id' => intval($item->id),
                        'caption' => $caption // to be displayed during playback
                    )),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'plugin_file://icons/song1.png',
                    ViewItemParams::item_detailed_icon_path => 'plugin_file://icons/song1.png'
                )
            );
        }
        
        return $ui_items;
    }
    */
    

    private function get_folder_views()
    {
        //return Config::GET_VOD_CATEGORY_LIST_FOLDER_VIEWS();
        return Config::GET_VOD_AUDIO_FOLDER_VIEWS();
    }
}


?>
