<?php
require_once 'lib/abstract_preloaded_regular_screen.php';

/*
 * Root screen wich should show 3 groups: videos, audios, photos
 */
class AudioTrackListScreen extends AbstractPreloadedRegularScreen
{
    private $l;
    const ID = 'audio_track_list';

    public static function get_media_url_str($ArtistID=null, $AlbumID=null, $Keyword=null)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'artist_id' => $ArtistID,
                'album_id' => $AlbumID,
                'keyword' => $Keyword,
            )
        );
    }

    public function __construct(MobileMediaLocalization $l)
    {
        $this->l = $l;
        parent::__construct(self::ID, $this->get_folder_views());
    }

    

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        return array(
            GUI_EVENT_KEY_ENTER => ActionFactory::vod_play(),
        );
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        //hd_print(__METHOD__);
        //hd_print('Media URL: ' . print_r($media_url, true));
        
            
        $url = '';
        
        if (!is_null($media_url->album_id)) {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_music_list&album=' . strval($media_url->album_id);
        } elseif (!is_null($media_url->artist_id)) {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_music_list&artist=' . strval($media_url->artist_id);
        } elseif (!is_null($media_url->keyword)) {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_music_list&search=' . strval($media_url->keyword);
        } else {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_music_list&root_id=0';
        }

        try
        {
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on server side: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        
        if (is_null($doc))
            throw new Exception('Can not fetch movie info');

        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        //hd_print("retrieved:\n".print_r($xml, true));
        
        $ui_items = array();
        
        foreach ($xml->items->item as $item)
        {
            $seconds = intval($item->length);
            $mins = floor( $seconds / 60 );
            $secs = floor( $seconds - ($mins*60) );
            $length = sprintf('%1$02d', $mins) 
                . ':' . sprintf('%1$02d', $secs);
            $caption = strval($item->author) 
                . ' - ' . strval($item->album) 
                . ' - ' . strval($item->title) 
                . ' - ' . $length;
            
            //hd_print("operating item:\n".print_r($item, true));
            $ui_items[] = array
            (
                PluginRegularFolderItem::media_url => 
                    MediaURL::encode(array(
                        'audio_id' => strval($item->id),
                        'caption' => $caption // to be displayed during playback
                    )),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'plugin_file://icons/song1.png',
                    ViewItemParams::item_detailed_icon_path => 'plugin_file://icons/song1.png'
                )
            );
        }
        
        return $ui_items;
    }

    

    private function get_folder_views()
    {
        //return Config::GET_VOD_CATEGORY_LIST_FOLDER_VIEWS();
        return Config::GET_VOD_AUDIO_FOLDER_VIEWS();
    }
}
