<?php


class FolderListScreen extends AbstractPreloadedRegularScreen
{
    private $l;
    const ID = 'folder_list';

    public static function get_media_url_str($type = 'videos', $folder_id = 0)
    {
        return MediaURL::encode(
            array
            (
                'screen_id' => self::ID,
                'type' => $type,
                'folder_id' => $folder_id,
            )
        );
    }

    

    public function __construct(MobileMediaLocalization $l)
    {
        $this->l = $l;
        parent::__construct(self::ID, $this->get_folder_views());
    }

    

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        return array(
            GUI_EVENT_KEY_ENTER => ActionFactory::open_folder(),
            GUI_EVENT_KEY_PLAY => ActionFactory::open_folder(),
        );
    }

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        if ($media_url->type == 'videos') {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_videos_list&root_id='.strval($media_url->folder_id);
                
        } elseif ($media_url->type == 'photos') {
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_photos_list&root_id='.strval($media_url->folder_id);
        }
        
        try
        {
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on server side: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        if (is_null($doc))
            throw new Exception('Can not fetch movie info');

        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        
        //hd_print("retrieved:\n".print_r($xml, true));
        $ui_items = array();
        
        
        foreach ($xml->items->item as $item)
        {
            hd_print("operating item:\n".print_r($item, true));
            // <-- need item->node=leaf|branch here
            
            $m = '';
            $title = strval($item->title);
            $icon_path = 'plugin_file://icons/folder.png';
            
            if ($item->node == 'leaf') { // show leaf content listing
                if ($media_url->type == 'videos') {
                    $m = MoviesListScreen::get_media_url_str( $folder_id=strval($item->id) );
                } elseif ($media_url->type == 'photos') {
                    $m = PhotosListScreen::get_media_url_str( $folder_id=strval($item->id) );
                }
            } elseif ($item->node == 'branch') { // recurse deeper down
                if ($media_url->type == 'videos') {
                    $m = FolderListScreen::get_media_url_str($type='videos', $folder_id=strval($item->id));
                } elseif ($media_url->type == 'photos') {
                    $m = FolderListScreen::get_media_url_str($type='photos', $folder_id=strval($item->id));
                }
            }
            
            $ui_items[] = array
            (
                PluginRegularFolderItem::media_url => $m,
                PluginRegularFolderItem::caption => $title,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => $icon_path,
                    ViewItemParams::item_detailed_icon_path => $icon_path
                )
            );
        }
        
        hd_print(print_r($ui_items, true));
        
        return $ui_items;
    }
    
    

    private function get_folder_views()
    {
        return Config::GET_VOD_CATEGORY_LIST_FOLDER_VIEWS();
    }
}
