<?php


require_once 'lib/abstract_preloaded_regular_screen.php';


/*
 * Root screen wich should show 3 groups: videos, audios, photos
 */
class ImageViewerScreen extends VodSeriesListScreen
    implements UserInputHandler
{
    const ID = 'image_viewer';
    
    private $xml_cache = null;
    
    public function get_id()
    { return self::ID; }
    
    // internal stash for lazy-loading 
    private $items_list = array();

    public static function get_media_url_str($photo_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'photo_id' => $photo_id,
            )
        );
    }

    

    public function __construct(Vod $vod=null)
    {
        //parent::__construct(self::ID, $this->get_folder_views());
        parent::__construct($vod, self::get_my_folder_views());
    }
    
    public function get_handler_id()
    { return self::ID.'_handler'; }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        if ($user_input->control_id === 'open_image')
        {
            return null;
        }
        
        return null;
    }


    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = array();
        
        $show_action = UserInputHandlerRegistry::create_action(
            $handler = $this, 
            $name = 'open_image');
        $actions[GUI_EVENT_KEY_ENTER] = $show_action;
        $actions[GUI_EVENT_KEY_PLAY] = $show_action;
        
        return $actions;
    }

    
    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $photo_id = $media_url->photo_id;
        $full_icon_path = 'http://'.Config::get_server_ip($plugin_cookies) 
            . '/server?cmd=get_photo&index=' . $photo_id . '&width=900&height=900';
        hd_print('full image path: ' . $full_icon_path);
        
        $ui_items[] = array
        (
            PluginRegularFolderItem::media_url => MediaURL::encode(array('photo_id' => intval($photo_id))),
            //PluginRegularFolderItem::media_url => 'show_image://http://172.24.218.26:8088/server?cmd=get_photo&index='.$item->id,
            PluginRegularFolderItem::caption => 'photo_'.$photo_id,
            PluginRegularFolderItem::view_item_params => array
            (
                ViewItemParams::icon_path => $full_icon_path,
                ViewItemParams::item_detailed_icon_path => $full_icon_path,
            )
        );
        
        return $ui_items;
    }
    
    
    public static function get_my_folder_views()
    {
        return Config::GET_IMAGE_VIEWER_FOLDER_VIEWS();
    }
}
