<?php

class MoviesListScreen extends AbstractPreloadedRegularScreen
{
    private $l;
    const ID = 'movie_list';

    public static function get_media_url_str($folder_id)
    {
        return MediaURL::encode(
            array
            (
                'screen_id' => self::ID,
                'folder_id' => $folder_id
            ));
    }

    

    public function __construct(MobileMediaLocalization $l)
    {
        $this->l = $l;
        parent::__construct(
            self::ID, $this->get_folder_views());
    }

    

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        return array(
            GUI_EVENT_KEY_ENTER => ActionFactory::vod_play(),
            GUI_EVENT_KEY_PLAY => ActionFactory::vod_play(),
        );
    }

    

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        try
        {
            //$url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_videos_list';
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                    . '/server?cmd=get_videos_list&root_id='.strval($media_url->folder_id);
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on device: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        
        $doc = HD::http_get_document($url);
     
        if (is_null($doc))
            throw new Exception('Can not fetch movie info');

        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        
        //hd_print("retrieved:\n".print_r($xml, true));
        
		$ui_items = array();
		
		foreach ($xml->items->item as $item)
        {
            $seconds = intval($item->length);
            $type = $item->type; // video type, not used
            
            $hours = floor( $seconds/(60*60) );
            $mins = floor( ($seconds - ($hours*60*60)) / 60 );
            $secs = floor( $seconds - ($hours*60*60) - ($mins*60) );
            $caption = sprintf('%1$02d', $hours) 
                . ':' . sprintf('%1$02d', $mins) 
                . ':' . sprintf('%1$02d', $secs);
            
            //hd_print("operating item:\n".print_r($item, true));
        	$ui_items[] = array
            (
                PluginRegularFolderItem::media_url => 
                    MediaURL::encode(array(
                        'movie_id' => strval($item->id),
                        'caption' => $caption // to be displayed during playback
                    )),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_video&index='.$item->id.'&thumbnail=true',
                    //ViewItemParams::icon_path => '',
                    ViewItemParams::item_detailed_icon_path => ''
                )
            );
            
            /*
            $tn_url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_video&index='.$item->id.'&thumbnail=true';
            hd_print('thumbnail_url: ' . $tn_url);
            copy($tn_url, '/D/tn/'. strtolower($item->id.'.'.$item->extension));
            */
        }
        
        return $ui_items;
    }

    

    private function get_folder_views()
    {
        return Config::GET_VOD_MOVIE_LIST_FOLDER_VIEWS();
    }
}


?>
