<?php

class PhotosListScreen extends VodSeriesListScreen
	implements UserInputHandler
{
    const ID = 'photos_list';
    
    private $l;
    
    public function get_id()
    { return self::ID; }
    
    //private $xml_cache = null;
    // internal stash for lazy-loading 
    //private $items_list = array();
    
    // reset $items_list if this changes and we are loading from a different iPhone
    private $last_used_ip = null; 

    public static function get_media_url_str($folder_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'folder_id' => $folder_id,
            )
        );
    }

    

    public function __construct(Vod $vod=null, MobileMediaLocalization $l)
    {
        $this->l = $l;
        parent::__construct($vod, self::get_my_folder_views());
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }
	
	public function get_handler_id()
	{ return self::ID.'_handler'; }

    public function handle_user_input(&$user_input, &$plugin_cookies)
	{
	    $selected_media_url = json_decode($user_input->selected_media_url);
        
		if ($user_input->control_id === 'open_image')
		{
		    $toBeReturned = ActionFactory::launch_media_url(
                //'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index=' . $selected_media_url->photo_id
                'http://'.Config::get_server_ip($plugin_cookies).'/server/image_' 
                . $selected_media_url->photo_id 
                . '.' . strtolower($selected_media_url->photo_type)
                // we had to make this hack with a path because launch_media_url needs a jpg file with no params on the end
            );
            
            // try using a plylist instead
            //$toBeReturned = ActionFactory::launch_media_url($plugin_cookies->latest_photo_playlist);
            
            hd_print(print_r($toBeReturned, true));
            
            return $toBeReturned;
		}
		
		return null;
	}

    

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
		$actions = array();
		
        $show_action = UserInputHandlerRegistry::create_action(
			$handler = $this, 
			$name = 'open_image');
		$actions[GUI_EVENT_KEY_ENTER] = $show_action;
		$actions[GUI_EVENT_KEY_PLAY] = $show_action;
		
		//$actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        //$actions[GUI_EVENT_KEY_PLAY] = ActionFactory::open_folder();
        
		return $actions;
    }

    
    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        try
        {
            //$url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photos_list';
            $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                . '/server?cmd=get_photos_list&root_id=' . strval($media_url->folder_id);
            $doc = HD::http_get_document($url);
        } catch (Exception $e)
        {
            throw new DuneException(
                'Something wrong on server side: ' . $url . ' could not be reached' ,
                0,
                ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
            );
        }
        
        //hd_print("XML response: \n" . $doc);
        
        $xml = simplexml_load_string($doc);
        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text:\n$doc\n");
            throw new Exception('Illegal XML document');
        }
        
        $items = array();
        
        foreach ($xml->items->item as $item)
        {
            $caption = $this->l->get_term('Photo') . ' ' . strval($item->id);
                
            $items[] = array
            (
                PluginRegularFolderItem::media_url => MediaURL::encode(
                    array(
                        'photo_id' => strval($item->id), 
                        'photo_type' => strval(strtolower($item->extension)),
                        'caption' => $caption // to be displayed during playback
                    )
                ),
                //PluginRegularFolderItem::media_url => 'show_image://http://172.24.218.26:8088/server?cmd=get_photo&index='.$item->id,
                //PluginRegularFolderItem::media_url => ImageViewerScreen::get_media_url_str(intval($item->id)),
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => 
                        'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index='.$item->id.'&thumbnail=true',
                    ViewItemParams::item_detailed_icon_path => null,
                        //'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index='.$item->id,
                )
            );
            
            /*
            $tn_url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index='.$item->id.'&thumbnail=true';
            hd_print('thumbnail_url: ' . $tn_url);
            copy($tn_url, '/D/tn/'. strtolower($item->id.'.'.$item->extension));
            */
        }
        
        return $items;
    }

    
    /*
    public function get_folder_range(MediaURL $media_url, $from_ndx, &$plugin_cookies)
    {
        hd_print(__METHOD__ . ' from ndx: ' . $from_ndx);
        
        if ( $this->last_used_ip != Config::get_server_ip($plugin_cookies) ) {
            // reset local cache and note latest IP
            $this->items_list = array();
            $this->last_used_ip = Config::get_server_ip($plugin_cookies);
        }
        
        $more_items_available = true;
        $partial_items = $this->get_some_folder_items($media_url, &$plugin_cookies, count($this->items_list), $more_items_available);
        $this->items_list = array_merge($this->items_list, $partial_items);
        
        return HD::create_regular_folder_range(
            $this->items_list, 
            $from_ndx = 0, // which element dune starts painting the list from
            $total = -1,
            $more_items_available
        );
        
    }
    
    private function get_some_folder_items(MediaURL $media_url, &$plugin_cookies, $from_ndx, &$more_items_available)
    {
        hd_print(__METHOD__);
        $per_page = 12;
        
        if (is_null($this->xml_cache))
        {
            try
            {
                //$url = 'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photos_list';
                $url = 'http://'.Config::get_server_ip($plugin_cookies) 
                    . '/server?cmd=get_photos_list&root_id='.strval($media_url->folder_id);
                $doc = HD::http_get_document($url);
            } catch (Exception $e)
            {
                throw new DuneException(
                    'Something wrong on server side: ' . $url . ' could not be reached' ,
                    0,
                    ActionFactory::show_error(false, $this->l->get_term('Device not responding'))
                );
            }
            
            $xml = simplexml_load_string($doc);
            if ($xml === false)
            {
                hd_print("Error: can not parse XML document.");
                hd_print("XML-text:\n$doc\n");
                throw new Exception('Illegal XML document');
            }
            
            $this->xml_cache = $xml;
            //$this->create_playlist($xml, $plugin_cookies);
        }
        
        //hd_print("retrieved:\n".print_r($xml, true));
        //hd_print('total number of items: ' . count($this->items_list));
        
        $ui_items = array();
        
        $media_url_str = 'dummy';
        
        //hd_print(count($this->items_list) . ' items already in list.');
        foreach ($this->xml_cache->items->item as $item)
        {
            //hd_print("operating item:\n".print_r($item, true));
            
            if ($item->id >= $from_ndx && $item->id < ($from_ndx + $per_page) )
            {
                hd_print(
                    'Artificial limit imposed: ' 
                    . $item->id . ' is between ' . $from_ndx 
                    . ' and ' . ($from_ndx + $per_page)
                );
                $caption = $this->l->get_term('Photo') . ' ' . $item->id;
                
                $ui_items[] = array
                (
                    PluginRegularFolderItem::media_url => MediaURL::encode(
                        array(
                            'photo_id' => strval($item->id), 
                            'photo_type' => strval(strtolower($item->extension)),
                            'caption' => $caption // to be displayed during playback
                        )
                    ),
                    //PluginRegularFolderItem::media_url => 'show_image://http://172.24.218.26:8088/server?cmd=get_photo&index='.$item->id,
                    //PluginRegularFolderItem::media_url => ImageViewerScreen::get_media_url_str(intval($item->id)),
                    PluginRegularFolderItem::caption => $caption,
                    PluginRegularFolderItem::view_item_params => array
                    (
                        ViewItemParams::icon_path => 
                            'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index='.$item->id.'&thumbnail=true',
                        ViewItemParams::item_detailed_icon_path => null,
                            //'http://'.Config::get_server_ip($plugin_cookies).'/server?cmd=get_photo&index='.$item->id,
                    )
                );
            }
            
        }
        
        hd_print('total items: ' . count($this->xml_cache->items->children()));        
        if (count($this->items_list) < count($this->xml_cache->items->children())) {
            $more_items_available = true;
        } else { $more_items_available = false; }
        
        return $ui_items;
    }
    */
    
    /* Redundant
    private function create_playlist(SimpleXMLElement $xml, &$plugin_cookies)
    {
        $playlist_path = DuneSystem::$properties['install_dir_path'] . '/playlists/photoplaylist.m3u';
        $playlist_content = "#EXTM3U\n\n";
        
        foreach ($this->xml_cache->items->item as $item)
        {
            $path = 'http://'.Config::get_server_ip($plugin_cookies).'/server/image_' 
                . $item->id 
                . '.' . strtolower($item->type);
            
            $playlist_content .= "#EXTINF\n".$path."\n";
        }
        
        file_put_contents($playlist_path, $playlist_content);
        hd_print('Assembled a playlist numbering ' . strlen($playlist_content) .' chars at ' . $playlist_path);
        $plugin_cookies->latest_photo_playlist = $playlist_path;
    }
    */
    
    public static function get_my_folder_views()
    {
        return Config::GET_IMAGE_LIST_FOLDER_VIEWS();
        //return Config::GET_VOD_MOVIE_LIST_FOLDER_VIEWS();
    }
}


?>
